<?php

/**
 * Admin area settings template file
 *
 * @link       https://kankode.com/
 * @since      1.0.0
 *
 * @package    Product_Search_Filters
 * @subpackage Psf_Product_Search_Filters/admin/partials
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

include 'global-header.php';
?>
    <ul class="primary-main-nav tabs-nav parent-tabs">
        <li class="active"><a href="#" data-tabgroup=".parent-tabs"
                              data-active=".search-settings"><?php esc_html_e( 'Search Settings', 'product-search-and-filters' ); ?></a>
        </li>
        <li><a href="#" data-tabgroup=".parent-tabs"
               data-active=".design-settings"><?php esc_html_e( 'Design Settings', 'product-search-and-filters' ); ?></a>
        </li>
        <li><a href="#" data-tabgroup=".parent-tabs"
               data-active=".advanced-settings"><?php esc_html_e( 'Advanced Settings', 'product-search-and-filters' ); ?></a>
        </li>
    </ul>
<?php
if ( isset( $_POST['psf_product_nonce'] ) ) :
	$this->save_settings();
endif;

$attributes = wc_get_attribute_taxonomies();

global $wpdb;

// Get products using DB query for optimization
$products = $wpdb->get_results( $wpdb->prepare( "SELECT ID, post_title FROM $wpdb->posts WHERE post_type = '%s' AND post_status = '%s'", 'product', 'publish' ), ARRAY_N );

// Get categories
$categories = get_terms( [ 'taxonomy' => 'product_cat', 'number' => 0 ] );

// Get settings
$settings = get_option( 'psf_search_settings' );

$build_required = (int) get_option( 'psf_cache_build_required' );

if ( $build_required ):
	echo '<div class="psf-cache-build-notice settings-notices notice notice-warning"><p><strong>' . esc_html__( 'Product cache build required! ', 'product-search-and-filters' ) . '</strong> <buton type="button" class="psf-button-link psf-build-cache-button psf-pull-right">' . esc_html__( 'Build now', 'product-search-and-filters' ) . '</buton></p></div>';
endif;
?>

    <div class="psf-progress-bar-wrapper" style="display: none;">
        <div class="psf-progress-bar">
            <div class="psf-progress" style="width:10%"></div>
        </div>

        <div class="psf-cache-build-warning-notice settings-notices notice notice-warning">
            <p>
                <strong><?php esc_html_e( 'Please keep this browser window open until the cache build is completed.', 'product-search-and-filters' ); ?></strong>
            </p>
        </div>
    </div>
    <div class="psf-cache-build-success-notice settings-notices notice notice-success"
         style="display: none;"><p>
            <strong><?php esc_html_e( 'Cache build is successful.', 'product-search-and-filters' ); ?></strong>
        </p></div>

    <form method="POST" action="">
        <div class="content-area tabs-box parent-tabs search-settings">
            <div class="content-header-area">
                <ul class="secondary-main-nav tabs-nav child-tabs">
                    <li class="active"><a href="#" data-tabgroup=".child-tabs"
                                          data-active=".smart-search"><?php esc_html_e( 'Smart Search', 'product-search-and-filters' ); ?></a>
                    </li>
                    <li><a href="#" data-tabgroup=".child-tabs"
                           data-active=".search-text"><?php esc_html_e( 'Search Text', 'product-search-and-filters' ); ?></a>
                    </li>
                    <li><a href="#" data-tabgroup=".child-tabs"
                           data-active=".sidebar-settings"><?php esc_html_e( 'Filter Settings', 'product-search-and-filters' ); ?></a>
                    </li>
                </ul>
            </div>
            <div class="content-body-area">
                <div class="form-ui clearfix child-tabs tabs-box smart-search">

                    <label class="label"><?php esc_html_e( 'Override WooCommerce Search?', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="sc_yes" class="toggle toggle-left"
                               name="override_woocommerce_search" value="yes"
                               type="radio" <?php echo ( $settings['override_woocommerce_search'] == 'yes' ) ? 'checked' : ''; ?>>
                        <label for="sc_yes"
                               class="custom-radio-btn"><?php esc_html_e( 'Yes', 'product-search-and-filters' ); ?></label>

                        <input id="sc_no" class="toggle toggle-right"
                               name="override_woocommerce_search" value="no"
                               type="radio" <?php echo ( $settings['override_woocommerce_search'] == 'no' ) ? 'checked' : ''; ?>>
                        <label for="sc_no"
                               class="custom-radio-btn"><?php esc_html_e( 'No', 'product-search-and-filters' ); ?></label>
                        <br>
                        <small><?php esc_html_e( 'You can override woocommerce search', 'product-search-and-filters' ); ?></small>
                    </div>

                    <label for="suggestion_characters"
                           class="label"><?php esc_html_e( 'Suggestion Characters', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="suggestion_characters" type="number"
                               name="suggestion_characters"
                               value="<?php echo ( $settings['suggestion_characters'] ) ? esc_attr( $settings['suggestion_characters'] ) : ''; ?>">
                        <small><?php esc_html_e( 'Show search results once (x) amount of characters have been entered.', 'product-search-and-filters' ); ?></small>
                    </div>

                    <label class="label"
                           for="suggestion_amount"><?php esc_html_e( 'Products per page', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="suggestion_amount" type="number"
                               name="suggestion_amount"
                               value="<?php echo ( $settings['suggestion_amount'] ) ? esc_attr( $settings['suggestion_amount'] ) : ''; ?>">
                        <small><?php esc_html_e( 'Show x amount of products per page.', 'product-search-and-filters' ); ?></small>
                    </div>

                    <label class="label"
                           for="exclude_products"><?php esc_html_e( 'Exclude Products', 'product-search-and-filters' ); ?></label>
                    <div>
                        <select id="exclude_products" type="text"
                                name="exclude_products[]"
                                class="select2_field_product" multiple>
                            <option></option>
							<?php
							$selected = '';
							foreach ( $products as $key => $product ) {
								if ( isset( $settings['exclude_products'] ) ) {
									if ( is_array( $settings['exclude_products'] ) ) {
										$selected = ( in_array( $product[0], $settings['exclude_products'] ) ) ? 'selected' : '';
									}
								}
								echo '<option value="' . esc_attr( $product[0] ) . '" ' . esc_attr( $selected ) . '>' . esc_html( $product[1] ) . '</option>';
							}
							?>
                        </select>
                        <small><?php esc_html_e( 'If chosen, these products will be excluded from the search results.', 'product-search-and-filters' ); ?></small>
                    </div>

                    <label class="label"
                           for="exclude_categories"><?php esc_html_e( 'Exclude Categories', 'product-search-and-filters' ); ?></label>
                    <div>
                        <select id="exclude_categories" type="text"
                                name="exclude_categories[]"
                                class="select2_field_category" multiple>
                            <option></option>
							<?php
							$selected = '';
							foreach ( $categories as $key => $category ) {
								if ( isset( $settings['exclude_categories'] ) ) {
									if ( is_array( $settings['exclude_categories'] ) ) {
										$selected = ( in_array( $category->term_id, $settings['exclude_categories'] ) ) ? 'selected' : '';
									}
								}
								echo '<option value="' . esc_attr( $category->term_id ) . '" ' . esc_attr( $selected ) . '>' . esc_html( $category->name ) . '</option>';
							}
							?>
                        </select>
                        <small><?php esc_html_e( 'If chosen, these categories and their products will be excluded from the search results.', 'product-search-and-filters' ); ?></small>
                    </div>

                    <label class="label"><?php esc_html_e( 'Search Parameters', 'product-search-and-filters' ); ?></label>
                    <div>
						<?php
						$sku_selected  = '';
						$name_selected = '';
						$desc_selected = '';
						if ( is_array( $settings['search_params'] ) ) {
							$sku_selected  = ( in_array( 'sku', $settings['search_params'] ) ) ? 'checked' : '';
							$name_selected = ( in_array( 'name', $settings['search_params'] ) ) ? 'checked' : '';
							$desc_selected = ( in_array( 'description', $settings['search_params'] ) ) ? 'checked' : '';
						}

						?>
                        <input type="checkbox" id="sku" name="search_params[]"
                               value="sku" <?php esc_attr_e( $sku_selected ); ?>>
                        <label for="sku"><?php esc_html_e( 'SKU', 'product-search-and-filters' ); ?></label>
                        <br>
                        <input type="checkbox" id="name" name="search_params[]"
                               value="name" <?php esc_attr_e( $name_selected ); ?>>
                        <label for="title"><?php esc_html_e( 'Title', 'product-search-and-filters' ); ?></label>
                        <br>
                        <input type="checkbox" id="description"
                               name="search_params[]"
                               value="description" <?php esc_attr_e( $desc_selected ); ?>>
                        <label for="description"><?php esc_html_e( 'Description', 'product-search-and-filters' ); ?></label>
                    </div>

                    <label class="label"
                           for="search_parameter_fields"><?php esc_html_e( 'Search Parameter (Custom Fields)', 'product-search-and-filters' ); ?></label>
                    <div>
                        <select id="search_parameter_fields" type="text"
                                name="search_parameter_fields[]"
                                class="select2_field_custom_fields" multiple>
                            <option></option>
							<?php
							$selected = '';
							foreach ( $custom_fields as $key => $custom_field ) {
								if ( isset( $settings['search_parameter_fields'] ) ) {
									if ( is_array( $settings['search_parameter_fields'] ) ) {
										$selected = ( in_array( $custom_field, $settings['search_parameter_fields'] ) ) ? 'selected' : '';
									}
								}
								echo '<option value="' . esc_attr( $custom_field ) . '" ' . esc_attr( $selected ) . '>' . esc_html( $custom_field ) . '</option>';
							}
							?>
                        </select>
                        <small><?php esc_html_e( 'If you are using custom fields within WooCommerce, the search results will include it\'s data when searching for a product. For example, if you have an online book store, you could include the "author" field here and it will be used to determine the results shown', 'product-search-and-filters' ); ?>
                            .</small>
                    </div>

                    <label class="label"><?php esc_html_e( 'Exclude Products', 'product-search-and-filters' ); ?>
                        <br> <?php esc_html_e( 'Out of Stock?', 'product-search-and-filters' ); ?>
                    </label>
                    <div>
                        <input id="ofs_yes" class="toggle toggle-left"
                               name="out_of_stock" value="yes"
                               type="radio" <?php echo ( $settings['out_of_stock'] == 'yes' ) ? 'checked' : ''; ?>>
                        <label for="ofs_yes"
                               class="custom-radio-btn"><?php esc_html_e( 'Yes', 'product-search-and-filters' ); ?></label>

                        <input id="ofs_no" class="toggle toggle-right"
                               name="out_of_stock" value="no"
                               type="radio" <?php echo ( $settings['out_of_stock'] == 'no' ) ? 'checked' : ''; ?>>
                        <label for="ofs_no"
                               class="custom-radio-btn"><?php esc_html_e( 'No', 'product-search-and-filters' ); ?></label>
                    </div>
                </div>

                <div class="form-ui clearfix child-tabs tabs-box search-text"
                     style="display: none;">
                    <label class="label"
                           for="search_placeholder"><?php esc_html_e( 'Search Placeholder', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="search_placeholder" type="text"
                               name="search_placeholder"
                               placeholder="Search for a product..."
                               value="<?php echo ( $settings['search_placeholder'] ) ? esc_attr( $settings['search_placeholder'] ) : ''; ?>">
                        <small><?php esc_html_e( 'Text that displays inside the search box.', 'product-search-and-filters' ); ?></small>
                    </div>
                </div>

                <div class="form-ui clearfix child-tabs tabs-box sidebar-settings"
                     style="display: none;">
                    <label class="label"><?php esc_html_e( 'Show Sidebar?', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="show_sidebar_yes" class="toggle toggle-left"
                               name="show_sidebar" value="yes"
                               type="radio" <?php echo ( $settings['show_sidebar'] == 'yes' ) ? 'checked' : ''; ?>>
                        <label for="show_sidebar_yes"
                               class="custom-radio-btn"><?php esc_html_e( 'Yes', 'product-search-and-filters' ); ?></label>

                        <input id="show_sidebar_no" class="toggle toggle-right"
                               name="show_sidebar" value="no"
                               type="radio" <?php echo ( $settings['show_sidebar'] == 'no' ) ? 'checked' : ''; ?>>
                        <label for="show_sidebar_no"
                               class="custom-radio-btn"><?php esc_html_e( 'No', 'product-search-and-filters' ); ?></label>
                        <br>
                        <small><?php esc_html_e( 'Select to show filters and search combined.', 'product-search-and-filters' ); ?></small>
                    </div>

                    <label class="label"
                           for="sidebar-attributes"><?php esc_html_e( 'Select attributes to display', 'product-search-and-filters' ); ?> </label>
                    <div>
                        <select id="sidebar_attributes" type="text"
                                name="sidebar_attributes[]"
                                class="select2_field_attribute"
                                multiple>
                            <option></option>
							<?php
							$selected = '';
							foreach ( $attributes as $key => $attribute ) {
								$attribute_name = 'pa_' . $attribute->attribute_name;
								if ( is_array( $settings['sidebar_attributes'] ) ) {
									$selected = ( in_array( $attribute_name, $settings['sidebar_attributes'] ) ) ? 'selected' : '';
								}
								echo '<option value="' . esc_attr( $attribute_name ) . '" ' . esc_attr( $selected ) . '>' . esc_html( $attribute->attribute_label ) . '</option>';
							}
							?>
                        </select><br>
                        <small><?php esc_html_e( 'These can be used to filter the search results.', 'product-search-and-filters' ); ?>
                            <br><?php esc_html_e( 'Leave empty to disable.', 'product-search-and-filters' ); ?>
                        </small>
                    </div>
                </div>

            </div>
        </div>

        <div class="content-area tabs-box parent-tabs design-settings"
             style="display: none;">
            <div class="content-header-area">
                <ul class="secondary-main-nav tabs-nav child-tabs">
                    <li class="active"><a href="#" data-tabgroup=".child-tabs"
                                          data-active=".theme-colors"><?php esc_html_e( 'Theme Colors', 'product-search-and-filters' ); ?></a>
                    </li>
                    <li><a href="#" data-tabgroup=".child-tabs"
                           data-active=".content-settings"><?php esc_html_e( 'Content Settings', 'product-search-and-filters' ); ?></a>
                    </li>
                    <li><a href="#" data-tabgroup=".child-tabs"
                           data-active=".brand-settings"><?php esc_html_e( 'Brand Settings', 'product-search-and-filters' ); ?></a>
                    </li>
                </ul>
            </div>
            <div class="content-body-area">
                <div class="form-ui clearfix child-tabs tabs-box theme-colors">
                    <label class="label"
                           for="primary-color"><?php esc_html_e( 'Primary Color', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="primary_color" type="color"
                               name="primary_color"
                               value="<?php echo ( $settings['primary_color'] ) ? esc_attr( $settings['primary_color'] ) : ''; ?>">
                        <br>
                        <small><?php esc_html_e( 'Primary color is used for product price and promotions.', 'product-search-and-filters' ); ?> </small>
                    </div>

                    <label class="label"
                           for="secondary-color"><?php esc_html_e( 'Secondary Color', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="secondary_color" type="color"
                               name="secondary_color"
                               value="<?php echo ( $settings['secondary_color'] ) ? esc_attr( $settings['secondary_color'] ) : ''; ?>">
                        <br>
                        <small><?php esc_html_e( 'Secondary color is used for stock display and delivery display.', 'product-search-and-filters' ); ?> </small>
                    </div>

                    <label class="label"
                           for="text-color"><?php esc_html_e( 'Text Color', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="text-color" type="color" name="text_color"
                               value="<?php echo ( $settings['text_color'] ) ? esc_attr( $settings['text_color'] ) : ''; ?>">
                    </div>

                    <label class="label"
                           for="add-to-cart-bg-color">
						<?php esc_html_e( 'Add to cart button', 'product-search-and-filters' ); ?>
                        <br><?php esc_html_e( 'background color', 'product-search-and-filters' ); ?>
                    </label>
                    <div>
                        <input id="add-to-cart-bg-color" type="color"
                               name="add_to_cart_bg_color"
                               value="<?php echo ( isset( $settings['add_to_cart_bg_color'] ) && $settings['add_to_cart_bg_color'] ) ? esc_attr( $settings['add_to_cart_bg_color'] ) : ''; ?>">
                    </div>

                    <label class="label"
                           for="add-to-cart-text-color">
						<?php esc_html_e( 'Add to cart button', 'product-search-and-filters' ); ?>
                        <br><?php esc_html_e( 'text color', 'product-search-and-filters' ); ?>
                    </label>
                    <div>
                        <input id="add-to-cart-text-color" type="color"
                               name="add_to_cart_text_color"
                               value="<?php echo ( isset( $settings['add_to_cart_text_color'] ) && $settings['add_to_cart_text_color'] ) ? esc_attr( $settings['add_to_cart_text_color'] ) : ''; ?>">
                    </div>

                    <label class="label"
                           for="add-to-cart-bg-hover-color"><?php esc_html_e( 'Add to cart button background hover color', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="add-to-cart-bg-hover-color" type="color"
                               name="add_to_cart_bg_hover_color"
                               value="<?php echo ( isset( $settings['add_to_cart_bg_hover_color'] ) && $settings['add_to_cart_bg_hover_color'] ) ? esc_attr( $settings['add_to_cart_bg_hover_color'] ) : ''; ?>">
                    </div>

                    <label class="label"
                           for="add-to-cart-text-hover-color">
						<?php esc_html_e( 'Add to cart button', 'product-search-and-filters' ); ?>
                        <br><?php esc_html_e( 'text hover color', 'product-search-and-filters' ); ?>
                    </label>
                    <div>
                        <input id="add-to-cart-text-hover-color" type="color"
                               name="add_to_cart_text_hover_color"
                               value="<?php echo ( isset( $settings['add_to_cart_text_hover_color'] ) && $settings['add_to_cart_text_hover_color'] ) ? esc_attr( $settings['add_to_cart_text_hover_color'] ) : ''; ?>">
                    </div>
                </div>
                <div class="form-ui clearfix child-tabs tabs-box content-settings"
                     style="display: none;">
                    <label class="label"><?php esc_html_e( 'Display Product', 'product-search-and-filters' ); ?>
                        <br> <?php esc_html_e( 'Stock Status?', 'product-search-and-filters' ); ?>
                    </label>
                    <div>
                        <input id="dp_stock_status_yes"
                               class="toggle toggle-left" name="dp_stock_status"
                               value="yes"
                               type="radio" <?php echo ( $settings['dp_stock_status'] == 'yes' ) ? 'checked' : ''; ?>>
                        <label for="dp_stock_status_yes"
                               class="custom-radio-btn"><?php esc_html_e( 'Yes', 'product-search-and-filters' ); ?></label>

                        <input id="dp_stock_status_no"
                               class="toggle toggle-right"
                               name="dp_stock_status" value="no"
                               type="radio" <?php echo ( $settings['dp_stock_status'] == 'no' ) ? 'checked' : ''; ?>>
                        <label for="dp_stock_status_no"
                               class="custom-radio-btn"><?php esc_html_e( 'No', 'product-search-and-filters' ); ?></label>
                    </div>

                    <label class="label">
						<?php esc_html_e( 'Display add to cart', 'product-search-and-filters' ); ?>
                        <br> <?php esc_html_e( 'button?', 'product-search-and-filters' ); ?>
                    </label>
                    <div>
                        <input id="dp_add_to_cart_yes"
                               class="toggle toggle-left" name="dp_add_to_cart"
                               value="yes"
                               type="radio" <?php echo ( isset( $settings['dp_add_to_cart'] ) && $settings['dp_add_to_cart'] == 'yes' ) ? 'checked' : ''; ?>>
                        <label for="dp_add_to_cart_yes"
                               class="custom-radio-btn"><?php esc_html_e( 'Yes', 'product-search-and-filters' ); ?></label>

                        <input id="dp_add_to_cart_no"
                               class="toggle toggle-right"
                               name="dp_add_to_cart" value="no"
                               type="radio" <?php echo ( isset( $settings['dp_add_to_cart'] ) && $settings['dp_add_to_cart'] == 'no' ) ? 'checked' : ''; ?>>
                        <label for="dp_add_to_cart_no"
                               class="custom-radio-btn"><?php esc_html_e( 'No', 'product-search-and-filters' ); ?></label>
                    </div>

                    <label class="label"><?php esc_html_e( 'Display Delivery', 'product-search-and-filters' ); ?>
                        <br><?php esc_html_e( 'Promotion?', 'product-search-and-filters' ); ?>
                    </label>
                    <div>
                        <input id="dd_promotion_yes" class="toggle toggle-left"
                               name="dd_promotion" value="yes"
                               type="radio" <?php echo ( $settings['dd_promotion'] == 'yes' ) ? 'checked' : ''; ?>>
                        <label for="dd_promotion_yes"
                               class="custom-radio-btn"><?php esc_html_e( 'Yes', 'product-search-and-filters' ); ?></label>

                        <input id="dd_promotion_no" class="toggle toggle-right"
                               name="dd_promotion" value="no"
                               type="radio" <?php echo ( $settings['dd_promotion'] == 'no' ) ? 'checked' : ''; ?>>
                        <label for="dd_promotion_no"
                               class="custom-radio-btn"><?php esc_html_e( 'No', 'product-search-and-filters' ); ?></label>
                    </div>

                    <label class="label"
                           for="delivery-details"><?php esc_html_e( 'Delivery Promotion Price', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="delivery_details" type="text"
                               name="delivery_details" placeholder="40"
                               value="<?php echo ( $settings['delivery_details'] ) ? esc_attr( $settings['delivery_details'] ) : ''; ?>">
                        <small><?php esc_html_e( 'Show Delivery promotion if the product price is  more than (x).', 'product-search-and-filters' ); ?> </small>
                    </div>

                    <label class="label"
                           for="delivery-promotion-text"><?php esc_html_e( 'Delivery Promotion', 'product-search-and-filters' ); ?>
                        <br> <?php esc_html_e( 'Text', 'product-search-and-filters' ); ?>
                    </label>
                    <div>
                        <input id="delivery_promotion_text" type="text"
                               name="delivery_promotion_text"
                               placeholder="<?php esc_attr_e( 'e.g. Free Delivery or Discounted Delivery', 'product-search-and-filters' ); ?>"
                               value="<?php echo ( $settings['delivery_promotion_text'] ) ? esc_attr( $settings['delivery_promotion_text'] ) : ''; ?>">
                        <small><?php esc_html_e( 'Displays in the top right corner.', 'product-search-and-filters' ); ?> </small>
                    </div>

                    <label class="label"
                           for="tax_text"><?php esc_html_e( 'Display text after Price?', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="tax_text" type="text" name="tax_text"
                               placeholder="<?php esc_attr_e( 'e.g. Tax appear after price', 'product-search-and-filters' ); ?>"
                               value="<?php echo ( $settings['tax_text'] ) ? esc_attr( $settings['tax_text'] ) : ''; ?>">
                        <small><?php esc_html_e( 'Displays after the price.', 'product-search-and-filters' ); ?></small>
                    </div>

                    <label class="label"><?php esc_html_e( 'Display Sale Banner', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="ds_banner_yes" class="toggle toggle-left"
                               name="display_sale_banner" value="yes"
                               type="radio" <?php echo ( $settings['display_sale_banner'] == 'yes' ) ? 'checked' : ''; ?>>
                        <label for="ds_banner_yes"
                               class="custom-radio-btn"><?php esc_html_e( 'Yes', 'product-search-and-filters' ); ?></label>

                        <input id="ds_banner_no" class="toggle toggle-right"
                               name="display_sale_banner" value="no"
                               type="radio" <?php echo ( $settings['display_sale_banner'] == 'no' ) ? 'checked' : ''; ?>>
                        <label for="ds_banner_no"
                               class="custom-radio-btn"><?php esc_html_e( 'No', 'product-search-and-filters' ); ?></label>
                    </div>

                    <label class="label"
                           for="sale-banner-text"><?php esc_html_e( 'Sale Banner Text', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="sale_banner_text" type="text"
                               name="sale_banner_text"
                               placeholder="Offer ends soon"
                               value="<?php echo ( $settings['sale_banner_text'] ) ? esc_attr( $settings['sale_banner_text'] ) : ''; ?>">
                    </div>
                </div>
                <div class="form-ui clearfix child-tabs tabs-box brand-settings"
                     style="display: none;">
                    <label class="label"><?php esc_html_e( 'Display Product', 'product-search-and-filters' ); ?>
                        <br><?php esc_html_e( 'Brand Logo', 'product-search-and-filters' ); ?>
                    </label>
                    <div>
                        <input id="dp_brand_logo_yes" class="toggle toggle-left"
                               name="display_product_brand_logo"
                               value="yes"
                               type="radio" <?php echo ( $settings['display_product_brand_logo'] == 'yes' ) ? 'checked' : ''; ?>>
                        <label for="dp_brand_logo_yes"
                               class="custom-radio-btn"><?php esc_html_e( 'Yes', 'product-search-and-filters' ); ?></label>

                        <input id="dp_brand_logo_no" class="toggle toggle-right"
                               name="display_product_brand_logo"
                               value="no"
                               type="radio" <?php echo ( $settings['display_product_brand_logo'] == 'no' ) ? 'checked' : ''; ?>>
                        <label for="dp_brand_logo_no"
                               class="custom-radio-btn"><?php esc_html_e( 'No', 'product-search-and-filters' ); ?></label>
                        <br><small><?php esc_html_e( 'Please note, WooCommerce Brands plugin must be installed and activated.', 'product-search-and-filters' ); ?></small>

                    </div>
                </div>
            </div>
        </div>

        <div class="content-area tabs-box parent-tabs advanced-settings"
             style="display: none;">
            <div class="content-header-area">
                <ul class="secondary-main-nav tabs-nav child-tabs">
                    <li class="active"><a href="#" data-tabgroup=".child-tabs"
                                          data-active=".caching"><?php esc_html_e( 'Caching', 'product-search-and-filters' ); ?></a>
                    </li>
                    <li><a href="#" data-tabgroup=".child-tabs"
                           data-active=".custom-css"><?php esc_html_e( 'Custom CSS', 'product-search-and-filters' ); ?></a>
                    </li>
                </ul>
            </div>
            <div class="content-body-area">
                <div class="form-ui clearfix child-tabs tabs-box caching">
                    <label for="cache_size"
                           class="label"><?php esc_html_e( 'Cache Size', 'product-search-and-filters' ); ?></label>
                    <div>
                        <input id="cache_size" type="number" name="cache_size"
                               value="<?php echo ( $settings['cache_size'] ) ? esc_attr( $settings['cache_size'] ) : ''; ?>">
                        <small><?php esc_html_e( 'Number of products in cache data.', 'product-search-and-filters' ); ?></small>
                    </div>

                    <label for=""
                           class="label"><?php esc_html_e( 'Rebuild Cache', 'product-search-and-filters' ); ?></label>
                    <div>

                        <buton type="button"
                               class="save-settings-button-link psf-build-cache-button"><?php esc_html_e( 'Rebuild', 'product-search-and-filters' ); ?></buton>
                    </div>
                </div>
                <div class="form-ui clearfix child-tabs tabs-box custom-css"
                     style="display: none;">
                    <label class="label"><?php esc_html_e( 'Custom CSS', 'product-search-and-filters' ); ?></label>
                    <div>
						<textarea id="custom-css" name="custom_css"
                                  class="min-height-250"
                                  placeholder="<?php esc_attr_e( 'CSS here will override default styles.', 'product-search-and-filters' ); ?>"
                        ><?php echo ( $settings['custom_css'] ) ? esc_html( $settings['custom_css'] ) : ''; ?></textarea>
                    </div>
                </div>
            </div>
        </div>

        <div class="clearfix">
            <input type="hidden" name="psf_product_nonce"
                   value="<?php echo esc_attr( wp_create_nonce( 'psf-product-search-filter' ) ); ?>"/>
            <input type="submit" name="submit" value="Save Settings"
                   class="save-settings-button">
        </div>
    </form>

<?php
include 'global-footer.php';
