<?php

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Psf_Product_Search_Filters_Activator
 * @subpackage Psf_Product_Search_Filters/includes
 * @author     KanKode <hello@kankode.com>
 */
class Psf_Product_Search_Filters_Activator {

	/**
	 * Perform activities on plugin activate
	 */
	public function activate() {
		if ( ! class_exists( 'WooCommerce' ) ) {
			$die_msg = '<b>' . esc_html__( 'Product Search and Filters for WooCommerce', 'product-search-and-filters' ) . '</b> ';
			$die_msg .= esc_html__( 'requires you to install & activate', 'product-search-and-filters' ) . ' <b>';
			$die_msg .= esc_html__( 'WooCommerce Plugin', 'product-search-and-filters' ) . ' </b> ';
			$die_msg .= esc_html__( 'before activating it!', 'product-search-and-filters' ) . '<br><br>';
			$die_msg .= '<a href="javascript:history.back()">' . esc_html__( '<< Go Back To Plugins Page', 'product-search-and-filters' ) . '</a>';
			wp_die( $die_msg );
		}

		// Store default settings parameters
		$this->update_default_settings();

		// Possibly build product cache
		$cache_class = new Psf_Product_Search_Filters_Cache_Rebuild();
		$cache_class->may_be_build_cache();
	}

	public function update_default_settings() {
		if ( ! get_option( 'psf_search_settings', false ) ) {
			update_option( 'psf_search_settings', [
				'override_woocommerce_search'  => 'no',
				'suggestion_characters'        => 1,
				'suggestion_amount'            => 12,
				'search_params'                => [ 'name' ],
				'search_parameter_fields'      => [],
				'out_of_stock'                 => 'no',
				'search_placeholder'           => esc_attr__( 'Search for a product', 'product-search-and-filters' ),
				'search_failed'                => esc_attr__( 'No product found', 'product-search-and-filters' ),
				'show_all_results'             => esc_attr__( 'Show all results', 'product-search-and-filters' ),
				'show_sidebar'                 => 'yes',
				'sidebar_attributes'           => [],
				'primary_color'                => '#e40707',
				'secondary_color'              => '#000000',
				'text_color'                   => '#000000',
				'add_to_cart_bg_color'         => '#e40707',
				'add_to_cart_text_color'       => '#ededed',
				'add_to_cart_bg_hover_color'   => '#2271b1',
				'add_to_cart_text_hover_color' => '#ededed',
				'dp_stock_status'              => 'yes',
				'dp_add_to_cart'               => 'yes',
				'dd_promotion'                 => 'no',
				'tax_text'                     => '',
				'delivery_details'             => 10,
				'delivery_promotion_text'      => esc_attr__( 'Free Delivery', 'product-search-and-filters' ),
				'display_sale_banner'          => 'yes',
				'sale_banner_text'             => esc_attr__( 'Offer ends soon', 'product-search-and-filters' ),
				'display_product_brand_logo'   => 'no',
				'cache_size'                   => 100000,
				'custom_css'                   => '',
			] );

			// First time make the cache build required
			update_option( 'psf_cache_build_required', '1' );
		}
	}
}
