<?php
/**
 * Plugin Name: WooSearch - Product Search & Filters for WooCommerce
 * Plugin URI: https://www.persianscript.ir
 * Description: WooSearch - Improve the WooCommerce search experience. Sleek design, integrated product filters and lightning fast product search results.
 * Version: 1.0.4
 * Author: پرشین اسکریپت
 * Author URI: https://www.persianscript.ir
 * Developer: kankode.com
 * Developer URI: https://kankode.com/
 * Text Domain: product-search-and-filters
 * Domain Path: /languages
 *
 * WC requires at least: 5.8
 * WC tested up to: 5.8
 *
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

// Plugin version
define( 'PSF_PRODUCT_SEARCH_FILTERS_VERSION', '1.0.3' );
define( 'PSF_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
define( 'PSF_MAX_PRODUCT_COUNT', 300 );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/product-search-and-filters-activator.php
 */
function psf_activate_woocommerce_product_search() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/product-search-and-filters-activator.php';
	$psf_activate_plugin_class = new Psf_Product_Search_Filters_Activator();
	$psf_activate_plugin_class->activate();
}

register_activation_hook( __FILE__, 'psf_activate_woocommerce_product_search' );

if ( is_admin() ) {
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'psf_show_additional_links' );
}

/**
 * Show additional link in plugin actions
 *
 * @param $actions
 *
 * @return array
 */
function psf_show_additional_links( $actions ) {

	$custom_actions = [];

	// Documentation URL.
	$custom_actions['docs'] = sprintf( '<a href="%s">%s</a>', 'https://woosearch.kankode.com/documentation/', esc_html__( 'Docs', 'product-search-and-filters' ) );

	return array_merge( $custom_actions, $actions );
}

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/product-search-and-filters.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
if ( ! function_exists( 'psf_run_woocommerce_product_search' ) ) {
	function psf_run_woocommerce_product_search() {
		$plugin = new Psf_Product_Search_Filters();
		$plugin->run();
	}

	// Fire the plugin
	psf_run_woocommerce_product_search();
}

